--- ./db3/configure.uw	2002-12-20 06:36:49.000000000 -0800
+++ ./db3/configure	2005-05-14 10:44:08.230000002 -0700
@@ -19,7 +19,7 @@
 \
 distdir install check:\
 \
-db4_install: all install_setip' > Makefile
+db4_install: all install_setip' -e "s/^LIBS=/LIBS=	-lxti/" > Makefile
 
 mv db.h db.h.orig
 cat db.h.orig | sed \
--- ./db/dist/configure.uw	2002-09-20 07:02:22.000000000 -0700
+++ ./db/dist/configure	2005-05-14 10:44:08.250000007 -0700
@@ -16056,7 +16056,6 @@
 echo "${ECHO_T}$ac_cv_search_sched_yield" >&6
 if test "$ac_cv_search_sched_yield" != no; then
   test "$ac_cv_search_sched_yield" = "none required" || LIBS="$ac_cv_search_sched_yield $LIBS"
-  LOAD_LIBS="$LOAD_LIBS -lrt"
 fi
 
 fi
--- ./file/file.h.uw	2003-01-23 13:54:12.000000000 -0800
+++ ./file/file.h	2005-05-14 10:44:08.260000010 -0700
@@ -95,7 +95,7 @@
 	} value;		/* either number or string */
 	uint32_t mask;	/* mask before comparison with value */
 	char desc[MAXDESC];	/* description */
-} __attribute__((__packed__));
+};
 
 #define BIT(A)   (1 << (A))
 #define STRING_IGNORE_LOWERCASE		BIT(0)
--- ./file/file.c.uw	2003-02-14 13:10:44.000000000 -0800
+++ ./file/file.c	2005-05-14 10:44:08.260000027 -0700
@@ -72,7 +72,7 @@
 		wid = 1;
 	} else {
 		if ((f = fopen(fn, "r")) == NULL) {
-			error(EXIT_FAILURE, 0, "Cannot open `%s' (%s).\n", fn, strerror(errno));
+			_my_error(EXIT_FAILURE, 0, "Cannot open `%s' (%s).\n", fn, strerror(errno));
 			/*@notreached@*/
 		}
 
@@ -218,7 +218,7 @@
 	else {
 		if ((home = getenv("HOME")) != NULL) {
 			size_t nb = strlen(home) + 8;
-			usermagic = xmalloc(nb);
+			usermagic = malloc(nb);
 			(void)strcpy(usermagic, home);
 			(void)strcat(usermagic, "/.magic");
 			if (stat(usermagic, &sb)<0) 
--- ./file/system.h.uw	2003-01-23 13:55:37.000000000 -0800
+++ ./file/system.h	2005-05-14 10:44:08.260000048 -0700
@@ -43,6 +43,7 @@
 #endif
 
 #if defined(__LCLINT__)
+#if !defined(__USLC__)
 /*@-declundef @*/
 /*@exits@*/
 extern void error(int status, int errnum, const char *format, ...)
@@ -50,6 +51,7 @@
 	/*@globals fileSystem @*/
 	/*@modifies fileSystem @*/;
 /*@=declundef @*/
+#endif
 #else
 #if HAVE_ERROR && HAVE_ERROR_H
 #include <error.h>
@@ -246,6 +248,7 @@
  */
 /*@-shadow@*/
 /*@unused@*/ /*@exits@*/ /*@only@*/
+#ifndef __USLC__
 static inline void * vmefail(/*@unused@*/ size_t nb)
 	/*@globals fileSystem @*/
 	/*@modifies fileSystem @*/
@@ -257,6 +260,7 @@
 /*@=nullret@*/
 }
 /*@=shadow@*/
+#endif
 
 #if HAVE_MCHECK_H
 #include <mcheck.h>
@@ -286,9 +290,9 @@
 
 #if !defined(__LCLINT__)
 /* Memory allocation via macro defs to get meaningful locations from mtrace() */
-#define	xmalloc(_size) 		(malloc(_size) ? : vmefail(0))
-#define	xcalloc(_nmemb, _size)	(calloc((_nmemb), (_size)) ? : vmefail(0))
-#define	xrealloc(_ptr, _size)	(realloc((_ptr), (_size)) ? : vmefail(0))
+#define	xmalloc(_size) 		(malloc(_size))
+#define	xcalloc(_nmemb, _size)	(calloc((_nmemb), (_size)))
+#define	xrealloc(_ptr, _size)	(realloc((_ptr), (_size)))
 #define	xstrdup(_str)	(strcpy(xmalloc(strlen(_str)+1), (_str)))
 #endif
 
--- ./file/Makefile.in.uw	2003-07-16 10:05:23.000000000 -0700
+++ ./file/Makefile.in	2005-05-14 10:44:08.270000027 -0700
@@ -159,8 +159,8 @@
 noinst_PROGRAMS = file
 
 file_SOURCES = file.c
-file_LDFLAGS = -all-static
-file_LDADD = libfmagic.la
+file_LDFLAGS =
+file_LDADD = -lgetopt libfmagic.la
 
 man_MAGIC = magic.@fsect@
 #man_MANS = file.1 $(man_MAGIC)
--- ./file/fsmagic.c.uw	2003-01-23 13:50:17.000000000 -0800
+++ ./file/fsmagic.c	2005-05-14 10:44:08.270000046 -0700
@@ -208,7 +208,7 @@
 	case S_IFREG:
 		break;
 	default:
-		error(EXIT_FAILURE, 0, "invalid mode 0%o.\n", st->st_mode);
+		_my_error(EXIT_FAILURE, 0, "invalid mode 0%o.\n", st->st_mode);
 		/*@notreached@*/
 	}
 
@@ -288,7 +288,7 @@
 /*@-branchstate@*/
 	if (strcmp("-", fn) == 0) {
 		if (fstat(0, &fm->sb)<0) {
-			error(EXIT_FAILURE, 0, "cannot fstat `%s' (%s).\n", stdname,
+			_my_error(EXIT_FAILURE, 0, "cannot fstat `%s' (%s).\n", stdname,
 			      strerror(errno));
 			/*@notreached@*/
 		}
@@ -323,7 +323,7 @@
 	 * try looking at the first HOWMANY bytes
 	 */
 	if ((fm->nb = read(fm->fd, (char *)fm->buf, HOWMANY)) == -1) {
-		error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
+		_my_error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
 		/*@notreached@*/
 	}
 
--- ./file/compress.c.uw	2003-01-23 13:28:50.000000000 -0800
+++ ./file/compress.c	2005-05-14 10:44:08.270000067 -0700
@@ -108,7 +108,7 @@
 	errno = r;
 #endif
 	if (tfd == -1) {
-		error(EXIT_FAILURE, 0, "Can't create temporary file for pipe copy (%s)\n",
+		_my_error(EXIT_FAILURE, 0, "Can't create temporary file for pipe copy (%s)\n",
 		    strerror(errno));
 		/*@notreached@*/
 	}
@@ -123,13 +123,13 @@
 
 	switch (r) {
 	case -1:
-		error(EXIT_FAILURE, 0, "Error copying from pipe to temp file (%s)\n",
+		_my_error(EXIT_FAILURE, 0, "Error copying from pipe to temp file (%s)\n",
 		    strerror(errno));
 		/*@notreached@*/break;
 	case 0:
 		break;
 	default:
-		error(EXIT_FAILURE, 0, "Error while writing to temp file (%s)\n",
+		_my_error(EXIT_FAILURE, 0, "Error while writing to temp file (%s)\n",
 		    strerror(errno));
 		/*@notreached@*/
 	}
@@ -140,13 +140,13 @@
 	 * can still access the phantom inode.
 	 */
 	if ((fd = dup2(tfd, fd)) == -1) {
-		error(EXIT_FAILURE, 0, "Couldn't dup destcriptor for temp file(%s)\n",
+		_my_error(EXIT_FAILURE, 0, "Couldn't dup destcriptor for temp file(%s)\n",
 		    strerror(errno));
 		/*@notreached@*/
 	}
 	(void)close(tfd);
 	if (lseek(fd, (off_t)0, SEEK_SET) == (off_t)-1) {
-		error(EXIT_FAILURE, 0, "Couldn't seek on temp file (%s)\n", strerror(errno));
+		_my_error(EXIT_FAILURE, 0, "Couldn't seek on temp file (%s)\n", strerror(errno));
 		/*@notreached@*/
 	}
 	return fd;
@@ -243,7 +243,7 @@
 #endif
 
 	if (pipe(fdin) == -1 || pipe(fdout) == -1) {
-		error(EXIT_FAILURE, 0, "cannot create pipe (%s).\n", strerror(errno));	
+		_my_error(EXIT_FAILURE, 0, "cannot create pipe (%s).\n", strerror(errno));	
 		/*@notreached@*/
 	}
 
@@ -266,7 +266,7 @@
 		exit(EXIT_FAILURE);
 		/*@notreached@*/ break;
 	case -1:
-		error(EXIT_FAILURE, 0, "could not fork (%s).\n", strerror(errno));
+		_my_error(EXIT_FAILURE, 0, "could not fork (%s).\n", strerror(errno));
 		/*@notreached@*/break;
 
 	default: /* parent */
--- ./file/readelf.c.uw	2003-02-27 12:30:00.000000000 -0800
+++ ./file/readelf.c	2005-05-14 10:44:08.280000004 -0700
@@ -129,18 +129,18 @@
 	Elf64_Shdr sh64;
 
 	if (size != sh_size) {
-		error(EXIT_FAILURE, 0, "corrupted program header size.\n");
+		_my_error(EXIT_FAILURE, 0, "corrupted program header size.\n");
 		/*@notreached@*/
 	}
 
 	if (lseek(fm->fd, off, SEEK_SET) == -1) {
-		error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+		_my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 		/*@notreached@*/
 	}
 
 	for ( ; num; num--) {
 		if (read(fm->fd, sh_addr, size) == -1) {
-			error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
+			_my_error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 		if (shs_type == SHT_SYMTAB /* || shs_type == SHT_DYNSYM */) {
@@ -174,18 +174,18 @@
 	size_t offset, nameoffset;
 
 	if (size != ph_size) {
-		error(EXIT_FAILURE, 0, "corrupted program header size.\n");
+		_my_error(EXIT_FAILURE, 0, "corrupted program header size.\n");
 		/*@notreached@*/
 	}
 
 	if (lseek(fm->fd, off, SEEK_SET) == -1) {
-		error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+		_my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 		/*@notreached@*/
 	}
 
   	for ( ; num; num--) {
   		if (read(fm->fd, ph_addr, size) == -1) {
-  			error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
+  			_my_error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 
@@ -202,12 +202,12 @@
 			 * in the section.
 			 */
 			if (lseek(fm->fd, (off_t) ph_offset, SEEK_SET) == -1) {
-				error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+				_my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 				/*@notreached@*/
 			}
 			bufsize = read(fm->fd, nbuf, sizeof(nbuf));
 			if (bufsize == -1) {
-				error(EXIT_FAILURE, 0, ": " "read failed (%s).\n",
+				_my_error(EXIT_FAILURE, 0, ": " "read failed (%s).\n",
 				    strerror(errno));
 				/*@notreached@*/
 			}
@@ -314,7 +314,7 @@
 				}
 			}
 			if ((lseek(fm->fd, ph_offset + offset, SEEK_SET)) == -1) {
-			    error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+			    _my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 			    /*@notreached@*/
 			}
 			/*@switchbreak@*/ break;
@@ -393,7 +393,7 @@
 	int os_style = -1;
 
 	if (size != ph_size) {
-		error(EXIT_FAILURE, 0, "corrupted program header size.\n");
+		_my_error(EXIT_FAILURE, 0, "corrupted program header size.\n");
 		/*@notreached@*/
 	}
 
@@ -402,11 +402,11 @@
 	 */
 	for ( ; num; num--) {
 		if (lseek(fm->fd, off, SEEK_SET) == -1) {
-			error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+			_my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 		if (read(fm->fd, ph_addr, size) == -1) {
-			error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
+			_my_error(EXIT_FAILURE, 0, "read failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 		off += size;
@@ -418,12 +418,12 @@
 		 * in the section.
 		 */
 		if (lseek(fm->fd, (off_t) ph_offset, SEEK_SET) == -1) {
-			error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
+			_my_error(EXIT_FAILURE, 0, "lseek failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 		bufsize = read(fm->fd, nbuf, BUFSIZ);
 		if (bufsize == -1) {
-			error(EXIT_FAILURE, 0, ": " "read failed (%s).\n", strerror(errno));
+			_my_error(EXIT_FAILURE, 0, ": " "read failed (%s).\n", strerror(errno));
 			/*@notreached@*/
 		}
 		offset = 0;
--- ./file/softmagic.c.uw	2003-02-14 14:48:21.000000000 -0800
+++ ./file/softmagic.c	2005-05-14 10:44:08.350000008 -0700
@@ -112,7 +112,7 @@
 	break;
 
     default:
-	error(EXIT_FAILURE, 0, "invalid m->type (%d) in fmagicSPrint().\n", m->type);
+	_my_error(EXIT_FAILURE, 0, "invalid m->type (%d) in fmagicSPrint().\n", m->type);
 	/*@notreached@*/ break;
     }
     return(t);
@@ -390,7 +390,7 @@
     case REGEX:
 	return 1;
     default:
-	error(EXIT_FAILURE, 0, "invalid type %d in fmagicSConvert().\n", m->type);
+	_my_error(EXIT_FAILURE, 0, "invalid type %d in fmagicSConvert().\n", m->type);
 	/*@notreached@*/
 	return 0;
     }
@@ -843,7 +843,7 @@
 	rc = regcomp(&rx, m->value.s, REG_EXTENDED|REG_NOSUB);
 	if (rc) {
 	    (void) regerror(rc, &rx, errmsg, sizeof(errmsg));
-	    error(EXIT_FAILURE, 0, "regex error %d, (%s)\n", rc, errmsg);
+	    _my_error(EXIT_FAILURE, 0, "regex error %d, (%s)\n", rc, errmsg);
 	    /*@notreached@*/
 	} else {
 	    rc = regexec(&rx, p->buf, 0, NULL, 0);
@@ -852,7 +852,7 @@
     }
 	/*@notreached@*/ break;
     default:
-	error(EXIT_FAILURE, 0, "invalid type %d in fmagicSCheck().\n", m->type);
+	_my_error(EXIT_FAILURE, 0, "invalid type %d in fmagicSCheck().\n", m->type);
 	/*@notreached@*/
 	return 0;
     }
@@ -921,7 +921,7 @@
 
     default:
 	matched = 0;
-	error(EXIT_FAILURE, 0, "fmagicSCheck: can't happen: invalid relation %d.\n", m->reln);
+	_my_error(EXIT_FAILURE, 0, "fmagicSCheck: can't happen: invalid relation %d.\n", m->reln);
 	/*@notreached@*/ break;
     }
 
--- ./popt/Makefile.in.uw	2003-07-16 10:04:49.000000000 -0700
+++ ./popt/Makefile.in	2005-05-14 10:44:08.350000029 -0700
@@ -75,14 +75,14 @@
 INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
 INSTOBJEXT = @INSTOBJEXT@
 INTLBISON = @INTLBISON@
-INTLLIBS = @INTLLIBS@
+INTLLIBS = -lgnuintl
 INTLOBJS = @INTLOBJS@
 INTL_LIBTOOL_SUFFIX_PREFIX = @INTL_LIBTOOL_SUFFIX_PREFIX@
 LDFLAGS = @LDFLAGS@
 LIBICONV = @LIBICONV@
 LIBINTL = @LIBINTL@
 LIBOBJS = @LIBOBJS@
-LIBS = @LIBS@
+LIBS = @LIBS@ -lgnuintl
 LIBTOOL = @LIBTOOL@
 LN_S = @LN_S@
 LTLIBICONV = @LTLIBICONV@
@@ -171,13 +171,13 @@
 
 noinst_PROGRAMS = test1 test2 test3
 test1_SOURCES = test1.c
-test1_LDFLAGS = -all-static
+test1_LDFLAGS = 
 test1_LDADD = $(usrlib_LTLIBRARIES)
 test2_SOURCES = test2.c
-test2_LDFLAGS = -all-static
+test2_LDFLAGS = 
 test2_LDADD = $(usrlib_LTLIBRARIES)
 test3_SOURCES = test3.c
-test3_LDFLAGS = -all-static
+test3_LDFLAGS = 
 test3_LDADD = $(usrlib_LTLIBRARIES)
 
 noinst_SCRIPTS = testit.sh
--- ./rpmio/fts.c.uw	2003-01-06 09:32:46.000000000 -0800
+++ ./rpmio/fts.c	2005-05-14 10:44:08.350000053 -0700
@@ -53,7 +53,7 @@
 #   define _STAT_VER		0
 #   define __fxstat64(_stat_ver, _fd, _sbp)	fstat((_fd), (_sbp))
 #endif
-#if defined(sun)
+#if defined(sun) || defined(__USLC__)
 #   define __errno_location()	(&errno)
 #   define dirfd(dirp)		-1
 #   define _STAT_VER		0
@@ -73,8 +73,12 @@
 /* Largest alignment size needed, minus one.
    Usually long double is the worst case.  */
 #ifndef ALIGNBYTES
+#if defined(__USLC__)
+#define ALIGNBYTES	(sizeof(long) - 1)
+#else
 #define ALIGNBYTES	(__alignof__ (long double) - 1)
 #endif
+#endif
 /* Align P to that size.  */
 #ifndef ALIGN
 #define	ALIGN(p)	(((unsigned long int) (p) + ALIGNBYTES) & ~ALIGNBYTES)
@@ -107,10 +111,14 @@
 	/*@modifies fileSystem, internalState @*/;
 
 #ifndef MAX
+#if defined(__USLC__)
+#define MAX(a,b)  ((a) > (b) ? (a) : (b))
+#else
 #define MAX(a, b)	({ __typeof__ (a) _a = (a); \
 			   __typeof__ (b) _b = (b); \
 			   _a > _b ? _a : _b; })
 #endif
+#endif
 
 #define	ISDOT(a)	(a[0] == '.' && (!a[1] || (a[1] == '.' && !a[2])))
 
--- ./rpmio/rpmrpc.c.uw	2003-05-29 15:14:04.000000000 -0700
+++ ./rpmio/rpmrpc.c	2005-05-14 10:44:08.350000073 -0700
@@ -1287,7 +1287,7 @@
     dp->d_ino = i + 1;		/* W2DO? */
     dp->d_reclen = 0;		/* W2DO? */
 
-#if !defined(hpux) && !defined(sun)
+#if !defined(hpux) && !defined(sun) && !defined(__USLC__)
     dp->d_off = 0;		/* W2DO? */
 /*@-boundsread@*/
     dp->d_type = dt[i];
--- ./rpmio/Makefile.in.uw	2003-07-16 10:05:49.000000000 -0700
+++ ./rpmio/Makefile.in	2005-05-14 10:44:08.360000014 -0700
@@ -288,8 +288,7 @@
 librpmio_la_LDFLAGS = -release 4.2 \
 	@WITH_BEECRYPT_LIB@ \
 	$(top_builddir)/file/libfmagic.la \
-	@WITH_ZLIB_LIB@ \
-	-lrt -lpthread
+	@WITH_ZLIB_LIB@
 
 librpmio_la_LIBADD = $(BEECRYPTLOBJS)
 librpmio_la_DEPENDENCIES = .created
--- ./rpmio/fts.h.uw	2003-01-06 09:32:46.000000000 -0800
+++ ./rpmio/fts.h	2005-05-14 10:44:08.360000027 -0700
@@ -51,7 +51,7 @@
 # define	_LARGEFILE64_SOURCE
 #endif
 
-#if defined(sun)
+#if defined(sun) || defined(__USLC__)
 # define _D_EXACT_NAMLEN(d) ((d)->d_reclen)
 #endif
 
--- ./rpmdb/legacy.c.uw	2002-12-18 14:40:19.000000000 -0800
+++ ./rpmdb/legacy.c	2005-05-14 10:44:08.360000042 -0700
@@ -183,8 +183,10 @@
 	}
 
 #ifdef	MADV_SEQUENTIAL
+#ifndef __USLC__
         xx = madvise(mapped, fsize, MADV_SEQUENTIAL);
 #endif
+#endif
 
 	ctx = rpmDigestInit(PGPHASHALGO_MD5, RPMDIGEST_NONE);
 	xx = rpmDigestUpdate(ctx, mapped, fsize);
--- ./lib/fsm.c.uw	2003-03-03 11:38:32.000000000 -0800
+++ ./lib/fsm.c	2005-05-14 10:44:08.370000014 -0700
@@ -880,8 +880,10 @@
 	    fsm->rdbuf = (char *) mapped;
 	    fsm->rdlen = nmapped = st->st_size;
 #if defined(MADV_DONTNEED)
+#ifndef __USLC__
 	    xx = madvise(mapped, nmapped, MADV_DONTNEED);
 #endif
+#endif
 	}
 #endif
 
@@ -910,8 +912,10 @@
 	if (mapped != (void *)-1) {
 	    xx = msync(mapped, nmapped, MS_ASYNC);
 #if defined(MADV_DONTNEED)
+#ifndef __USLC__
 	    xx = madvise(mapped, nmapped, MADV_DONTNEED);
 #endif
+#endif
 	    /*@-noeffect@*/ xx = munmap(mapped, nmapped) /*@=noeffect@*/;
 	    fsm->rdbuf = rdbuf;
 	}
--- ./build/rpmfile.h.uw	2003-01-23 13:54:12.000000000 -0800
+++ ./build/rpmfile.h	2005-05-14 10:44:08.370000027 -0700
@@ -95,7 +95,7 @@
 	} value;		/* either number or string */
 	uint32_t mask;	/* mask before comparison with value */
 	char desc[MAXDESC];	/* description */
-} __attribute__((__packed__));
+};
 
 #define BIT(A)   (1 << (A))
 #define STRING_IGNORE_LOWERCASE		BIT(0)
--- ./misc/glob.h.uw	2000-03-11 12:59:30.000000000 -0800
+++ ./misc/glob.h	2005-05-14 10:44:08.370000039 -0700
@@ -151,7 +151,7 @@
    `glob' returns GLOB_ABEND; if it returns zero, the error is ignored.
    If memory cannot be allocated for PGLOB, GLOB_NOSPACE is returned.
    Otherwise, `glob' returns zero.  */
-#if _FILE_OFFSET_BITS != 64
+#if (_FILE_OFFSET_BITS != 64) || defined(__USLC__)
 extern int glob __P ((__const char *__pattern, int __flags,
 		      int (*__errfunc) (__const char *, int),
 		      glob_t *__pglob));
--- ./tools/Makefile.in.uw	2003-07-16 10:05:51.000000000 -0700
+++ ./tools/Makefile.in	2005-05-14 10:44:08.380000006 -0700
@@ -90,7 +90,7 @@
 INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
 INSTOBJEXT = @INSTOBJEXT@
 INTLBISON = @INTLBISON@
-INTLLIBS = @INTLLIBS@
+INTLLIBS = -lgnuintl -lgetopt
 INTLOBJS = @INTLOBJS@
 INTL_LIBTOOL_SUFFIX_PREFIX = @INTL_LIBTOOL_SUFFIX_PREFIX@
 LDFLAGS = @LDFLAGS@
@@ -98,17 +98,17 @@
 LDFLAGS_STATIC = @LDFLAGS_STATIC@
 LIBDIR = @LIBDIR@
 LIBICONV = @LIBICONV@
-LIBINTL = @LIBINTL@
+LIBINTL = -lgnuintl -lgetopt
 LIBMISC = @LIBMISC@
 LIBOBJS = @LIBOBJS@
 LIBRPMALIAS_FILENAME = @LIBRPMALIAS_FILENAME@
 LIBRPMRC_FILENAME = @LIBRPMRC_FILENAME@
-LIBS = @LIBS@
+LIBS = @LIBS@ -lgnuintl -lgetopt
 LIBTOOL = @LIBTOOL@
 LN_S = @LN_S@
 LOCALEDIR = @LOCALEDIR@
 LTLIBICONV = @LTLIBICONV@
-LTLIBINTL = @LTLIBINTL@
+LTLIBINTL = -lgnuintl -lgetopt
 LTLIBOBJS = @LTLIBOBJS@
 MACROFILES = @MACROFILES@
 MAKEINFO = @MAKEINFO@
@@ -275,7 +275,7 @@
 
 LDADD = \
 	$(top_builddir)/lib/librpm.la \
-	@INTLLIBS@
+	-lgnuintl -lgetopt
 
 
 staticLDFLAGS = @LDFLAGS_STATIC@ @LDFLAGS_NPTL@
@@ -285,7 +285,7 @@
 
 
 pkgbindir = @RPMCONFIGDIR@
-pkgbin_PROGRAMS = debugedit javadeps rpmcache rpmdeps rpmfile
+pkgbin_PROGRAMS = javadeps rpmcache rpmdeps rpmfile
 
 bin_PROGRAMS = rpmgraph
 
@@ -325,7 +325,7 @@
 noinst_PROGRAMS = convertdb1$(EXEEXT) dump$(EXEEXT) dumpdb$(EXEEXT) \
 	rpmarchive$(EXEEXT) rpmheader$(EXEEXT) rpmlead$(EXEEXT) \
 	rpmsignature$(EXEEXT)
-pkgbin_PROGRAMS = debugedit$(EXEEXT) javadeps$(EXEEXT) rpmcache$(EXEEXT) \
+pkgbin_PROGRAMS = javadeps$(EXEEXT) rpmcache$(EXEEXT) \
 	rpmdeps$(EXEEXT) rpmfile$(EXEEXT)
 PROGRAMS = $(bin_PROGRAMS) $(noinst_PROGRAMS) $(pkgbin_PROGRAMS)
 
--- ./configure.uw	2003-07-16 10:05:55.000000000 -0700
+++ ./configure	2005-05-14 10:51:35.450000003 -0700
@@ -1,4 +1,4 @@
-#! /bin/sh
+#! /bin/bash
 # Guess values for system-dependent variables and create Makefiles.
 # Generated by GNU Autoconf 2.57.
 #
@@ -85,7 +85,7 @@
 
 # The user is always right.
 if test "${PATH_SEPARATOR+set}" != set; then
-  echo "#! /bin/sh" >conf$$.sh
+  echo "#! /bin/bash" >conf$$.sh
   echo  "exit 0"   >>conf$$.sh
   chmod +x conf$$.sh
   if (PATH="/nonexistent;."; conf$$.sh) >/dev/null 2>&1; then
@@ -253,7 +253,7 @@
 
 
 # Check that we are running under the correct shell.
-SHELL=${CONFIG_SHELL-/bin/sh}
+SHELL=${CONFIG_SHELL-/bin/bash}
 
 case X$ECHO in
 X*--fallback-echo)
@@ -337,7 +337,7 @@
     elif (test -f /bin/ksh || test -f /bin/ksh$ac_exeext) &&
 	 test "X$CONFIG_SHELL" != X/bin/ksh; then
       # If we have ksh, try running configure again with it.
-      ORIGINAL_CONFIG_SHELL=${CONFIG_SHELL-/bin/sh}
+      ORIGINAL_CONFIG_SHELL=${CONFIG_SHELL-/bin/bash}
       export ORIGINAL_CONFIG_SHELL
       CONFIG_SHELL=/bin/ksh
       export CONFIG_SHELL
@@ -379,7 +379,7 @@
 	if test "$prev" != 'sed 50q "$0"'; then
 	  echo_test_string=`eval $prev`
 	  export echo_test_string
-	  exec ${ORIGINAL_CONFIG_SHELL-${CONFIG_SHELL-/bin/sh}} "$0" ${1+"$@"}
+	  exec ${ORIGINAL_CONFIG_SHELL-${CONFIG_SHELL-/bin/bash}} "$0" ${1+"$@"}
 	else
 	  # Oops.  We lost completely, so just stick with echo.
 	  echo=echo
@@ -415,7 +415,7 @@
 subdirs=
 MFLAGS=
 MAKEFLAGS=
-SHELL=${CONFIG_SHELL-/bin/sh}
+SHELL=${CONFIG_SHELL-/bin/bash}
 
 # Maximum number of lines to put in a shell here document.
 # This variable seems obsolete.  It should probably be removed, and
@@ -8030,9 +8030,8 @@
     no_undefined_flag=' -z text'
     # $CC -shared without GNU ld will not create a library from C++
     # object files and a static libstdc++, better avoid it by now
-    archive_cmds='$LD -G${allow_undefined_flag} -h $soname -o $lib $libobjs $deplibs $linker_flags'
-    archive_expsym_cmds='$echo "{ global:" > $lib.exp~cat $export_symbols | sed -e "s/\(.*\)/\1;/" >> $lib.exp~$echo "local: *; };" >> $lib.exp~
-		$LD -G${allow_undefined_flag} -M $lib.exp -h $soname -o $lib $libobjs $deplibs $linker_flags~$rm $lib.exp'
+    archive_cmds='$LD -G${allow_undefined_flag} -h $rpath/$soname -o $lib $libobjs $deplibs $linker_flags'
+    archive_expsym_cmds='$LD -G${allow_undefined_flag} -Bexport:$export_symbols -h $rpath/$soname -o $lib $libobjs $deplibs $linker_flags'
     hardcode_libdir_flag_spec=
     hardcode_shlibpath_var=no
     runpath_var='LD_RUN_PATH'
@@ -16137,7 +16136,7 @@
 else
 
     CC="$CC" GCC="$GCC" LDFLAGS="$LDFLAGS" LD="$LD" with_gnu_ld="$with_gnu_ld" \
-    ${CONFIG_SHELL-/bin/sh} "$ac_aux_dir/config.rpath" "$host" > conftest.sh
+    ${CONFIG_SHELL-/bin/bash} "$ac_aux_dir/config.rpath" "$host" > conftest.sh
     . ./conftest.sh
     rm -f ./conftest.sh
     acl_cv_rpath=done
@@ -17908,7 +17907,7 @@
 
 
 if test X$gt_cv_func_gettext_libintl = Xyes ; then
-    LIBS="-lintl $LIBS"
+    LIBS="-lgnuintl $LIBS"
 fi
 
 echo "$as_me:$LINENO: checking for ANSI C header files" >&5
@@ -23806,7 +23805,7 @@
 
 # The user is always right.
 if test "${PATH_SEPARATOR+set}" != set; then
-  echo "#! /bin/sh" >conf$$.sh
+  echo "#! /bin/bash" >conf$$.sh
   echo  "exit 0"   >>conf$$.sh
   chmod +x conf$$.sh
   if (PATH="/nonexistent;."; conf$$.sh) >/dev/null 2>&1; then
--- ./Makefile.in.uw	2003-09-16 13:34:18.000000000 -0700
+++ ./Makefile.in	2005-05-14 10:44:08.530000027 -0700
@@ -91,7 +91,7 @@
 INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
 INSTOBJEXT = @INSTOBJEXT@
 INTLBISON = @INTLBISON@
-INTLLIBS = @INTLLIBS@
+INTLLIBS = -lgnuintl
 INTLOBJS = @INTLOBJS@
 INTL_LIBTOOL_SUFFIX_PREFIX = @INTL_LIBTOOL_SUFFIX_PREFIX@
 LDFLAGS = @LDFLAGS@
@@ -99,7 +99,7 @@
 LDFLAGS_STATIC = @LDFLAGS_STATIC@
 LIBDIR = @LIBDIR@
 LIBICONV = @LIBICONV@
-LIBINTL = @LIBINTL@
+LIBINTL = -lgnuintl
 LIBMISC = @LIBMISC@
 LIBOBJS = @LIBOBJS@
 LIBRPMALIAS_FILENAME = @LIBRPMALIAS_FILENAME@
@@ -109,7 +109,7 @@
 LN_S = @LN_S@
 LOCALEDIR = @LOCALEDIR@
 LTLIBICONV = @LTLIBICONV@
-LTLIBINTL = @LTLIBINTL@
+LTLIBINTL = -lgnuintl
 LTLIBOBJS = @LTLIBOBJS@
 MACROFILES = @MACROFILES@
 MAKEINFO = @MAKEINFO@
@@ -291,7 +291,7 @@
 	$(top_builddir)/rpmio/librpmio.la \
 	$(top_builddir)/popt/libpopt.la \
 	@WITH_ZLIB_LIB@ \
-	@INTLLIBS@ \
+	-lgnuintl \
 	@LIBMISC@
 
 
@@ -310,7 +310,7 @@
 
 rpm_SOURCES = 
 rpm_LDFLAGS = $(myLDFLAGS)
-rpm_LDADD = rpm.o $(top_builddir)/build/.libs/librpmbuild.a $(myLDADD)
+rpm_LDADD = rpm.o $(top_builddir)/build/.libs/librpmbuild.so $(myLDADD)
 
 rpmb_SOURCES = build.c
 rpmb_LDFLAGS = $(myLDFLAGS)
@@ -353,7 +353,7 @@
 
 am_rpm_OBJECTS =
 rpm_OBJECTS = $(am_rpm_OBJECTS)
-rpm_DEPENDENCIES = rpm.o $(top_builddir)/build/.libs/librpmbuild.a \
+rpm_DEPENDENCIES = rpm.o $(top_builddir)/build/.libs/librpmbuild.so \
 	$(top_builddir)/lib/librpm.la $(top_builddir)/rpmdb/librpmdb.la \
 	$(top_builddir)/rpmio/librpmio.la \
 	$(top_builddir)/popt/libpopt.la

--- ./file/print.c.uw	2003-01-23 13:27:22.000000000 -0800
+++ ./file/print.c	2005-05-14 10:44:08.270000011 -0700
@@ -133,11 +133,11 @@
 
 #if !defined(HAVE_ERROR) || defined(__LCLINT__)
 /*
  * error - print best error message possible and exit
  */
 /*VARARGS*/
 void
-error(int status, /*@unused@*/ int errnum, const char * format, ...)
+_my_error(int status, /*@unused@*/ int errnum, const char * format, ...)
 {
 	va_list va;
 
@@ -133,11 +133,11 @@
 #if !defined(HAVE_ERROR) || defined(__LCLINT__)
 /*
- * error - print best error message possible and exit
+ * _my_error - print best error message possible and exit
  */
 /*VARARGS*/